@@ -1,14 +1,16 @@
 /*
- * Iterator test cases for libgpiod.
+ * This file is part of libgpiod.
  *
- * Copyright (C) 2017 Bartosz Golaszewski <bartekgola@gmail.com>
+ * Copyright (C) 2017-2018 Bartosz Golaszewski <bartekgola@gmail.com>
  *
- * This library is free software; you can redistribute it and/or modify it
+ * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation; either version 2.1 of the License, or (at
  * your option) any later version.
  */
 
+/* Iterator test cases. */
+
 #include "gpiod-test.h"
 
 static void chip_iter(void)
@@ -23,8 +25,6 @@ static void chip_iter(void)
 	TEST_ASSERT_NOT_NULL(iter);
 
 	gpiod_foreach_chip(iter, chip) {
-		TEST_ASSERT(!gpiod_chip_iter_err(iter));
-
 		if (strcmp(gpiod_chip_label(chip), "gpio-mockup-A") == 0)
 			A = true;
 		else if (strcmp(gpiod_chip_label(chip), "gpio-mockup-B") == 0)
@@ -57,8 +57,6 @@ static void chip_iter_noclose(void)
 	TEST_ASSERT_NOT_NULL(iter);
 
 	gpiod_foreach_chip_noclose(iter, chip) {
-		TEST_ASSERT(!gpiod_chip_iter_err(iter));
-
 		if (strcmp(gpiod_chip_label(chip), "gpio-mockup-A") == 0) {
 			A = true;
 			chipA = chip;
@@ -99,8 +97,6 @@ static void chip_iter_break(void)
 	TEST_ASSERT_NOT_NULL(iter);
 
 	gpiod_foreach_chip(iter, chip) {
-		TEST_ASSERT(!gpiod_chip_iter_err(iter));
-
 		if ((strcmp(gpiod_chip_label(chip), "gpio-mockup-A") == 0) ||
 		    (strcmp(gpiod_chip_label(chip), "gpio-mockup-B") == 0) ||
 		    (strcmp(gpiod_chip_label(chip), "gpio-mockup-C") == 0))
@@ -121,18 +117,18 @@ TEST_DEFINE(chip_iter_break,
 
 static void line_iter(void)
 {
+	TEST_CLEANUP(test_free_line_iter) struct gpiod_line_iter *iter = NULL;
 	TEST_CLEANUP(test_close_chip) struct gpiod_chip *chip = NULL;
-	struct gpiod_line_iter iter;
 	struct gpiod_line *line;
 	unsigned int i = 0;
 
 	chip = gpiod_chip_open(test_chip_path(0));
 	TEST_ASSERT_NOT_NULL(chip);
 
-	gpiod_line_iter_init(&iter, chip);
+	iter = gpiod_line_iter_new(chip);
+	TEST_ASSERT_NOT_NULL(iter);
 
-	gpiod_foreach_line(&iter, line) {
-		TEST_ASSERT(!gpiod_line_iter_err(&iter));
+	gpiod_foreach_line(iter, line) {
 		TEST_ASSERT_EQ(i, gpiod_line_offset(line));
 		i++;
 	}
@@ -142,28 +138,3 @@ static void line_iter(void)
 TEST_DEFINE(line_iter,
 	    "gpiod_line_iter - simple loop, check offsets",
 	    0, { 8 });
-
-static void line_iter_static_initializer(void)
-{
-	TEST_CLEANUP(test_close_chip) struct gpiod_chip *chip = NULL;
-	struct gpiod_line *line;
-	unsigned int i = 0;
-
-	chip = gpiod_chip_open(test_chip_path(0));
-	TEST_ASSERT_NOT_NULL(chip);
-
-	{
-		struct gpiod_line_iter iter = GPIOD_LINE_ITER_INITIALIZER(chip);
-
-		gpiod_foreach_line(&iter, line) {
-			TEST_ASSERT(!gpiod_line_iter_err(&iter));
-			TEST_ASSERT_EQ(i, gpiod_line_offset(line));
-			i++;
-		}
-	}
-
-	TEST_ASSERT_EQ(8, i);
-}
-TEST_DEFINE(line_iter_static_initializer,
-	    "gpiod_line_iter - simple loop, static initializer",
-	    0, { 8 });
